==> zytec-js-api-1.1.5.tgz: package/jsapi.js <==
/*basic */
(function () {
    "use strict";
    var e = {}, a = navigator.userAgent, n = a.match(/Zytec\(\w+\/([a-zA-Z0-9.-]+)\)/);
    null === n && (n = a.match(/Zytec\/([a-zA-Z0-9.-]+)/));
    var i = n && n[1];
    e.debug = false;
    e.ios = /iPhone|iPad|iPod/i.test(a), e.android = /Android/i.test(a), e.version = i, e.cfg = {}, e.extend = function (e, a) {
        if (a) for (var n in a) e[n] = a[n];
        return e
    }, e.isZytec = function () {
        return e.version
    }, e.type = function (e) {
        return Object.prototype.toString.call(e).match(/^\[object\s(.*)\]$/)[1]
    }, "object" == typeof module && module && "object" == typeof module.exports ? module.exports = e : "function" == typeof define && (define.amd || define.cmd) && define(function () {
        return e
    }), "undefined" == typeof this.zytec && (this.zytec = e), this.__zytec = e
}).call(window),
    /*bridge*/
    function (zytec) {
        var bridge = {
            default: this, call: function (b, a, c) {
                var e = "";
                "function" == typeof a && (c = a, a = {});
                a = {data: a};
                if ("function" == typeof c) {
                    var g = "dscb" + window.dscb++;
                    window[g] = c;
                    a._dscbstub = g
                }
                a = JSON.stringify(a);
                if (window._dsbridge) e = _dsbridge.call(b, a); else if (window._dswk || -1 != navigator.userAgent.indexOf("_dsbridge")) e = prompt("_dsbridge=" + b, a);
                return JSON.parse(e || '{}').data
            }, register: function (b, a, c) {
                c = c ? window._dsaf : window._dsf;
                window._dsInit || (window._dsInit = !0, setTimeout(function () {
                        bridge.call("_dsb.dsinit")
                    },
                    0));
                "object" == typeof a ? c._obs[b] = a : c[b] = a
            }, registerAsyn: function (b, a) {
                this.register(b, a, !0)
            }, hasNativeMethod: function (b, a) {
                return this.call("_dsb.hasNativeMethod", {name: b, type: a || "all"})
            }, disableJavascriptDialogBlock: function (b) {
                this.call("_dsb.disableJavascriptDialogBlock", {disable: !1 !== b})
            }
        };
        !function () {
            if (!window._dsf) {
                var b = {
                    _dsf: {_obs: {}}, _dsaf: {_obs: {}}, dscb: 0, dsBridge: bridge, close: function () {
                        bridge.call("_dsb.closePage")
                    }, _handleMessageFromNative: function (a) {
                        var e = JSON.parse(a.data), b = {id: a.callbackId, complete: !0}, c = this._dsf[a.method],
                            d = this._dsaf[a.method], h = function (a, c) {
                                b.data = a.apply(c, e);
                                bridge.call("_dsb.returnValue", b)
                            }, k = function (a, c) {
                                e.push(function (a, c) {
                                    b.data = a;
                                    b.complete = !1 !== c;
                                    bridge.call("_dsb.returnValue", b)
                                });
                                a.apply(c, e)
                            };
                        if (c) h(c, this._dsf); else if (d) k(d, this._dsaf);
                        else if (c = a.method.split("."), !(2 > c.length)) {
                            a = c.pop();
                            var c = c.join("."), d = this._dsf._obs, d = d[c] || {}, f = d[a];
                            f && "function" == typeof f ? h(f, d) : (d = this._dsaf._obs, d = d[c] || {}, (f = d[a]) && "function" == typeof f && k(f, d))
                        }
                    }
                }, a;
                for (a in b) window[a] = b[a];
                bridge.register("_hasJavascriptMethod", function (a, b) {
                    b = a.split(".");
                    if (2 > b.length) return !(!_dsf[b] && !_dsaf[b]);
                    a = b.pop();
                    b = b.join(".");
                    return (b = _dsf._obs[b] || _dsaf._obs[b]) && !!b[a]
                })
            }
        }();
        zytec.extend(zytec, {bridge: bridge});
    }(__zytec),
    function (zytec) {
        "use strict";
        var a = "1.1.0", methods = {
            runtime: [
                {
                    namespace: "runtime.requestAuthCode",
                    name: "JS免登",
                    needAuth: false
                },
                {
                    namespace: "runtime.logout",
                    name: "退出应用",
                    needAuth: false
                },
                {
                    namespace: "runtime.mobileLogin",
                    name: "手机快速登录",
                    needAuth: false
                }
            ],
            biz:[
                {
                    namespace: "biz.getUserInfo",
                    name: "获取用户信息",
                    needAuth: false
                }
            ],
            navigator:[
                {
                    namespace: "navigator.close",
                    name: "退出浏览器",
                    needAuth: false
                },
            ]

        };
        zytec.extend(zytec, {sdk_version: a}), zytec.extend(zytec, {methods: methods})
    }(__zytec),
    function (zytec, window) {
        "use strict";
        document.addEventListener('zytec.ready', function (event) {
            if (zytec.readyCallback) {
                zytec.readyCallback(event.detail)
            }
        });
        document.addEventListener('zytec.error', function (event) {
            if (zytec.debug) {
                alert(event.detail);
            }
            if(zytec.errorCallback){
                zytec.errorCallback(event.detail)
            }
        });
        zytec.extend(zytec, {
            configSuccess: false,
            config: function (a) {
                var s;
                a && (s = {
                    org_id: a.org_id,
                    client_id: a.client_id || -1,
                    timestamp: a.timestamp,
                    noncestr: a.noncestr,
                    signature: a.signature,
                    type: a.type || 'jsapi',
                    url: a.url || null
                }) && (zytec.debug = a.debug || false);
                zytec.bridge.call('runtime.config', s, function (val) {
                    var event = document.createEvent('CustomEvent');
                    if (val.code === 1) {
                        zytec.configSuccess = true;
                        event.initCustomEvent('zytec.ready', true, true, val)
                    } else {
                        event.initCustomEvent('zytec.error', true, true, val ? val.message : null)
                    }
                    document.dispatchEvent(event)
                })
            }, error: function (callback) {
                this.errorCallback = callback
            }, ready: function (callback) {
                this.readyCallback = callback
            }
        });

        var generateFunc = function (a, n) {
            for (var i = a.split("."), o = zytec, s = 0, r = i.length; s < r; s++) s === r - 1 && (o[i[s]] = n), "undefined" == typeof o[i[s]] && (o[i[s]] = {}), o = o[i[s]]
        }, p = function (namespace, params, callback, method) {

            params = params || {},
                callback._onSuccess = callback.onSuccess || function () {
                };
            callback._onFail = callback.onFail || function () {
            };
            callback._onCancel = callback.onCancel || function () {
            };

            zytec.bridge.call(namespace, params, function (v) {
                callback.onSuccess = function () {
                    // alert(JSON.stringify(v));
                    callback._onSuccess.apply(this, [v.data]);
                };
                callback.onFail = function () {
                    callback._onFail.apply(this, [v.message]);
                };
                callback.onCancel = function () {
                    callback._onCancel.apply(this, [v.message]);
                };
                if (v.code == 1) {
                    callback.onSuccess()
                } else if (v.code == 0) {
                    callback.onFail()
                } else {
                    callback.onCancel()
                }
            })
        };
        for (var u in zytec.methods) zytec.methods[u].forEach(function (method) {
            generateFunc(method.namespace, function (params, callback) {
                if (method.needAuth && !zytec.configSuccess) {
                    zytec.debug && alert('没有配置zytec.config');
                    !zytec.debug && console.log('没有配置zytec.config');
                }
                return p(method.namespace, params, callback, method);
            })
        });
    }(__zytec, window);

==> zytec-js-api-1.1.6.tgz: package/jsapi.js <==
/*basic */
(function () {
    "use strict";
    var e = {}, a = navigator.userAgent, n = a.match(/Zytec\(\w+\/([a-zA-Z0-9.-]+)\)/);
    null === n && (n = a.match(/Zytec\/([a-zA-Z0-9.-]+)/));
    var i = n && n[1];
    e.debug = false;
    e.ios = /iPhone|iPad|iPod/i.test(a), e.android = /Android/i.test(a), e.version = i, e.cfg = {}, e.extend = function (e, a) {
        if (a) for (var n in a) e[n] = a[n];
        return e
    }, e.isZytec = function () {
        return e.version
    }, e.type = function (e) {
        return Object.prototype.toString.call(e).match(/^\[object\s(.*)\]$/)[1]
    }, "object" == typeof module && module && "object" == typeof module.exports ? module.exports = e : "function" == typeof define && (define.amd || define.cmd) && define(function () {
        return e
    }), "undefined" == typeof this.zytec && (this.zytec = e), this.__zytec = e
}).call(window),
    /*bridge*/
    function (zytec) {
        var bridge = {
            default: this, call: function (b, a, c) {
                var e = "";
                "function" == typeof a && (c = a, a = {});
                a = {data: a};
                if ("function" == typeof c) {
                    var g = "dscb" + window.dscb++;
                    window[g] = c;
                    a._dscbstub = g
                }
                a = JSON.stringify(a);
                if (window._dsbridge) e = _dsbridge.call(b, a); else if (window._dswk || -1 != navigator.userAgent.indexOf("_dsbridge")) e = prompt("_dsbridge=" + b, a);
                return JSON.parse(e || '{}').data
            }, register: function (b, a, c) {
                c = c ? window._dsaf : window._dsf;
                window._dsInit || (window._dsInit = !0, setTimeout(function () {
                        bridge.call("_dsb.dsinit")
                    },
                    0));
                "object" == typeof a ? c._obs[b] = a : c[b] = a
            }, registerAsyn: function (b, a) {
                this.register(b, a, !0)
            }, hasNativeMethod: function (b, a) {
                return this.call("_dsb.hasNativeMethod", {name: b, type: a || "all"})
            }, disableJavascriptDialogBlock: function (b) {
                this.call("_dsb.disableJavascriptDialogBlock", {disable: !1 !== b})
            }
        };
        !function () {
            if (!window._dsf) {
                var b = {
                    _dsf: {_obs: {}}, _dsaf: {_obs: {}}, dscb: 0, dsBridge: bridge, close: function () {
                        bridge.call("_dsb.closePage")
                    }, _handleMessageFromNative: function (a) {
                        var e = JSON.parse(a.data), b = {id: a.callbackId, complete: !0}, c = this._dsf[a.method],
                            d = this._dsaf[a.method], h = function (a, c) {
                                b.data = a.apply(c, e);
                                bridge.call("_dsb.returnValue", b)
                            }, k = function (a, c) {
                                e.push(function (a, c) {
                                    b.data = a;
                                    b.complete = !1 !== c;
                                    bridge.call("_dsb.returnValue", b)
                                });
                                a.apply(c, e)
                            };
                        if (c) h(c, this._dsf); else if (d) k(d, this._dsaf);
                        else if (c = a.method.split("."), !(2 > c.length)) {
                            a = c.pop();
                            var c = c.join("."), d = this._dsf._obs, d = d[c] || {}, f = d[a];
                            f && "function" == typeof f ? h(f, d) : (d = this._dsaf._obs, d = d[c] || {}, (f = d[a]) && "function" == typeof f && k(f, d))
                        }
                    }
                }, a;
                for (a in b) window[a] = b[a];
                bridge.register("_hasJavascriptMethod", function (a, b) {
                    b = a.split(".");
                    if (2 > b.length) return !(!_dsf[b] && !_dsaf[b]);
                    a = b.pop();
                    b = b.join(".");
                    return (b = _dsf._obs[b] || _dsaf._obs[b]) && !!b[a]
                })
            }
        }();
        zytec.extend(zytec, {bridge: bridge});
    }(__zytec),
    function (zytec) {
        "use strict";
        var a = "1.1.0", methods = {
            runtime: [
                {
                    namespace: "runtime.requestAuthCode",
                    name: "JS免登",
                    needAuth: false
                },
                {
                    namespace: "runtime.logout",
                    name: "退出应用",
                    needAuth: false
                },
                {
                    namespace: "runtime.login",
                    name: "用户登录",
                    needAuth: false
                },
                {

                    namespace: "runtime.closeWebview",
                    name: "关闭浏览器",
                    needAuth: false
                }
            ],
            biz:[
                {
                    namespace: "biz.refreshUserInfo",
                    name: "更新用户信息",
                    needAuth: false
                },
                {
                    namespace: "biz.getUserInfo",
                    name: "获取用户信息",
                    needAuth: false
                },
                {
                    namespace: "biz.scanQRCode",
                    name: "扫码",
                    needAuth: false
                }
            ],
            navigator:[
                {
                    namespace: "navigator.close",
                    name: "退出浏览器",
                    needAuth: false
                },
            ]

        };
        zytec.extend(zytec, {sdk_version: a}), zytec.extend(zytec, {methods: methods})
    }(__zytec),
    function (zytec, window) {
        "use strict";
        document.addEventListener('zytec.ready', function (event) {
            if (zytec.readyCallback) {
                zytec.readyCallback(event.detail)
            }
        });
        document.addEventListener('zytec.error', function (event) {
            if (zytec.debug) {
                alert(event.detail);
            }
            if(zytec.errorCallback){
                zytec.errorCallback(event.detail)
            }
        });
        zytec.extend(zytec, {
            configSuccess: false,
            config: function (a) {
                var s;
                a && (s = {
                    org_id: a.org_id,
                    client_id: a.client_id || -1,
                    timestamp: a.timestamp,
                    noncestr: a.noncestr,
                    signature: a.signature,
                    type: a.type || 'jsapi',
                    url: a.url || null
                }) && (zytec.debug = a.debug || false);
                zytec.bridge.call('runtime.config', s, function (val) {
                    var event = document.createEvent('CustomEvent');
                    if (val.code === 1) {
                        zytec.configSuccess = true;
                        event.initCustomEvent('zytec.ready', true, true, val)
                    } else {
                        event.initCustomEvent('zytec.error', true, true, val ? val.message : null)
                    }
                    document.dispatchEvent(event)
                })
            }, error: function (callback) {
                this.errorCallback = callback
            }, ready: function (callback) {
                this.readyCallback = callback
            }
        });

        var generateFunc = function (a, n) {
            for (var i = a.split("."), o = zytec, s = 0, r = i.length; s < r; s++) s === r - 1 && (o[i[s]] = n), "undefined" == typeof o[i[s]] && (o[i[s]] = {}), o = o[i[s]]
        }, p = function (namespace, params, callback, method) {

            params = params || {},
                callback._onSuccess = callback.onSuccess || function () {
                };
            callback._onFail = callback.onFail || function () {
            };
            callback._onCancel = callback.onCancel || function () {
            };

            zytec.bridge.call(namespace, params, function (v) {
                callback.onSuccess = function () {
                    // alert(JSON.stringify(v));
                    callback._onSuccess.apply(this, [v.data]);
                };
                callback.onFail = function () {
                    callback._onFail.apply(this, [v.message]);
                };
                callback.onCancel = function () {
                    callback._onCancel.apply(this, [v.message]);
                };
                if (v.code == 1) {
                    callback.onSuccess()
                } else if (v.code == 0) {
                    callback.onFail()
                } else {
                    callback.onCancel()
                }
            })
        };
        for (var u in zytec.methods) zytec.methods[u].forEach(function (method) {
            generateFunc(method.namespace, function (params, callback) {
                if (method.needAuth && !zytec.configSuccess) {
                    zytec.debug && alert('没有配置zytec.config');
                    !zytec.debug && console.log('没有配置zytec.config');
                }
                return p(method.namespace, params, callback, method);
            })
        });
    }(__zytec, window);
